@@ -113,7 +113,7 @@ def make_directory(survey, i=1):
     return survey
           
   
-def make_final_sample(survey):
+def make_final_sample(survey, cols_to_drop=['select_DG','TSM','SC3_bin_rank','drop','false','n_select']):
     """
     Makes a directory for the output files
 
@@ -161,17 +161,20 @@ def make_final_sample(survey):
     # we need to also add in our RM targets
     for target in survey.programs.loc['SC2Bii', 'high_priority']:
         survey.df.loc[survey.df['toi'] == target,'in_SC2Bii'] = 1
+        if np.isnan(survey.df.loc[survey.df['toi'] == target, 'priority'].values.tolist()[0]):
+            survey.df.loc[survey.df['toi'] == target, 'priority'] = survey.df['priority'].max()+1
     start = np.array([0]*len(survey.df))
     for science in survey.programs.index.values.tolist():
         start += survey.df['in_%s'%science].values.tolist()
     survey.df['in_other_programs'] = start
+    survey.df.drop(columns=cols_to_drop, errors='ignore', inplace=True)
     if survey.save:
         if survey.emcee:
             survey.df.to_csv('%s/%d/TOIs_perfect_final.csv'%(survey.path_save, survey.n), index=False)
         else:
-            survey.df.to_csv('%s/TOIs_perfect_final.csv'%survey.path_save, index=False)
+            survey.df.to_csv('%s/%s_final.csv'%(survey.path_save, (survey.path_sample.split('/')[-1]).split('.')[0]), index=False)
         if survey.verbose and not survey.emcee:
-            print('     - a copy of the updated sample info')
+            print('     - a copy of the updated sample')
     survey.final = survey.df.copy()
     return survey
       
@@ -198,6 +201,23 @@ def make_ranking_steps(survey):
     df = pd.DataFrame(columns = reorder)
     for column in reorder:
         df[column] = track[column]
+    tois = [int(target) for target in df.toi.values.tolist()]
+    idx = len(df)
+    for t, target in enumerate(survey.programs.loc['SC2Bii', 'high_priority']):
+        idx = len(df)
+        df.loc[idx+t,'program'] = 'SC2Bii'
+        df.loc[idx+t,'program_pick'] = t+1
+        df.loc[idx+t,'toi'] = target
+        df.loc[idx+t,'tic'] = survey.df[survey.df['toi'].isin([target])]['tic'].values.tolist()[0]
+        if int(np.floor(target)) not in tois:
+            df.loc[idx+t,'overall_priority'] = int(df['overall_priority'].max()+1)
+        else:
+            new=tois.index(int(np.floor(target)))
+            df.loc[idx+t,'overall_priority'] = df.loc[new,'overall_priority']
+            df.loc[idx+t,'tic'] = df.loc[new,'tic']
+        for program in survey.programs.index.values.tolist():
+            df.loc[idx+t,program] = df.loc[idx-1,program]
+        df.loc[idx+t,'total_time'] = df.loc[idx-1,'total_time']
     if survey.save:
         if survey.emcee:
             df.to_csv('%s/%d/ranking_steps.csv'%(survey.path_save,survey.n))
@@ -230,7 +250,7 @@ def assign_priorities(survey, obs={}, m=1):
     """
     track_sorted = survey.ranking_steps.sort_values(by = ['overall_priority'])
     for q in list(set(track_sorted.overall_priority.values.tolist())):
-        if not np.isnan(q):
+        if int(q) != 0:
             prior = track_sorted[track_sorted["overall_priority"] == q]
             obs[m] = {}
             obs[m]['tic'] = int(prior.tic.values.tolist()[0])
@@ -424,7 +444,7 @@ def get_stats(survey, note='', output='', finish=False):
     df = survey.overlap.copy()
     time = datetime.datetime.now()
     note += time.strftime("%a %m/%d/%y %I:%M%p") + '\n'
-    output += '\n' + time.strftime("%a %m/%d/%y %I:%M%p") + '\n'
+    output += time.strftime("%a %m/%d/%y %I:%M%p") + '\n\n'
     note += 'Seed no: %d\n'%survey.seeds[survey.n-1]
     note += 'Out of the %d total targets:\n'%len(df)
     output += 'Out of the %d total targets:\n'%len(df)
@@ -450,9 +470,9 @@ def get_stats(survey, note='', output='', finish=False):
         f.close()
         if survey.verbose and not survey.emcee:
             print('     - txt file w/ run info')
-            print('\n ------------------------')
-            print(' --- process complete ---')
-            print(' ------------------------')
+            print('\n ------------------------------')
+            print(' ----- process - complete -----')
+            print(' ------------------------------')
             print('')
             print(output)
 
